searchData={"items":[{"type":"module","title":"StacValidator","doc":"StacValidator provides functions for validating Spatio-Temporal Asset Catalog (STAC) metadata against the STAC specification.","ref":"StacValidator.html"},{"type":"function","title":"StacValidator.validate/2","doc":"Validates a STAC item, collection, or catalog against the STAC specification.","ref":"StacValidator.html#validate/2"},{"type":"function","title":"Examples - StacValidator.validate/2","doc":"","ref":"StacValidator.html#validate/2-examples"},{"type":"function","title":"Validating a STAC Item: - StacValidator.validate/2","doc":"iex> StacValidator.validate(%{\n    ...>   \"type\" => \"Feature\",\n    ...>   \"stac_version\" => \"1.0.0\",\n    ...>   \"id\" => \"example-item\",\n    ...>   \"geometry\" => nil,\n    ...>   \"properties\" => %{\n    ...>     \"datetime\" => \"2024-01-01T00:00:00Z\"\n    ...>   },\n    ...>   \"links\" => [],\n    ...>   \"assets\" => %{}\n    ...> })\n    {:ok, true}","ref":"StacValidator.html#validate/2-validating-a-stac-item"},{"type":"function","title":"Validating a STAC Collection: - StacValidator.validate/2","doc":"iex> StacValidator.validate(%{\n    ...>   \"type\" => \"Collection\",\n    ...>   \"stac_version\" => \"1.0.0\",\n    ...>   \"id\" => \"example-collection\",\n    ...>   \"description\" => \"A collection of STAC items\",\n    ...>   \"license\" => \"other\",\n    ...>   \"extent\" => %{\n    ...>     \"spatial\" => %{\n    ...>       \"bbox\" => [[-180.0, -90.0, 180.0, 90.0]]\n    ...>     },\n    ...>     \"temporal\" => %{\n    ...>       \"interval\" => [[\"2020-01-01T00:00:00Z\", nil]]\n    ...>     }\n    ...>   },\n    ...>   \"links\" => []\n    ...> })\n    {:ok, true}","ref":"StacValidator.html#validate/2-validating-a-stac-collection"},{"type":"function","title":"Validating a STAC Catalog: - StacValidator.validate/2","doc":"iex> StacValidator.validate(%{\n    ...>   \"type\" => \"Catalog\",\n    ...>   \"stac_version\" => \"1.0.0\",\n    ...>   \"id\" => \"example-catalog\",\n    ...>   \"description\" => \"A catalog of STAC collections and items\",\n    ...>   \"links\" => [\n    ...>     %{\n    ...>       \"rel\" => \"child\",\n    ...>       \"href\" => \"collection.json\",\n    ...>       \"type\" => \"application/json\"\n    ...>     }\n    ...>   ]\n    ...> })\n    {:ok, true}","ref":"StacValidator.html#validate/2-validating-a-stac-catalog"},{"type":"extras","title":"StacValidator","doc":"# StacValidator\n\nA library for validating SpatioTemporal Asset Catalog (STAC) metadata.","ref":"readme.html"},{"type":"extras","title":"Installation - StacValidator","doc":"The package can be installed by adding `stac_validator` to your list of dependencies in `mix.exs`:\n```elixir\ndef deps do\n  [\n    {:stac_validator, \"~> 0.1.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - StacValidator","doc":"```elixir\nitem = %{\n  \"type\" => \"Feature\",\n  \"stac_version\" => \"1.0.0\",\n  \"id\" => \"example-item\",\n  \"geometry\" => nil,\n  \"properties\" => %{\n    \"datetime\" => \"2024-01-01T00:00:00Z\"\n  },\n  \"links\" => [],\n  \"assets\" => %{}\n}\n\ncase StacValidator.validate(item) do\n  {:ok, true} -> IO.puts(\"Valid STAC item!\")\n  {:error, reason} -> IO.puts(\"Invalid STAC object: #{reason}\")\nend\n```\n\nThe documentation can be found at [https://hexdocs.pm/stac_validator](https://hexdocs.pm/stac_validator)","ref":"readme.html#usage"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}